@@ -2,26 +2,26 @@
 ### Encoding: UTF-8
 
 ###################################################
-### code chunk number 1: stream.Rnw:135-136
+### code chunk number 1: stream.Rnw:136-137
 ###################################################
 options(width = 75, digits = 3, prompt = 'R> ', scipen = 3)
 
 
 ###################################################
-### code chunk number 2: stream.Rnw:647-648
+### code chunk number 2: stream.Rnw:651-652
 ###################################################
 set.seed(1000)
 
 
 ###################################################
-### code chunk number 3: stream.Rnw:651-653
+### code chunk number 3: stream.Rnw:655-657
 ###################################################
 library("stream")
 stream <- DSD_Gaussians(k = 3, d = 2)
 
 
 ###################################################
-### code chunk number 4: stream.Rnw:658-660
+### code chunk number 4: stream.Rnw:666-668
 ###################################################
 dstream <- DSC_DStream(gridsize = .1, Cm = 1.2)
 update(dstream, stream, n = 500)
@@ -36,13 +36,13 @@ plot(km, stream, type = "both")
 
 
 ###################################################
-### code chunk number 6: stream.Rnw:875-876
+### code chunk number 6: stream.Rnw:884-885
 ###################################################
 set.seed(1000) 
 
 
 ###################################################
-### code chunk number 7: stream.Rnw:878-882
+### code chunk number 7: stream.Rnw:887-891
 ###################################################
 library("stream")
 
@@ -51,14 +51,14 @@ stream
 
 
 ###################################################
-### code chunk number 8: stream.Rnw:903-905
+### code chunk number 8: stream.Rnw:912-914
 ###################################################
 p <- get_points(stream, n = 5) 
 p 
 
 
 ###################################################
-### code chunk number 9: stream.Rnw:916-918
+### code chunk number 9: stream.Rnw:925-927
 ###################################################
 p <- get_points(stream, n = 100, class = TRUE) 
 head(p, n = 10)
@@ -77,7 +77,7 @@ plot(stream, n = 500, method = "pc")
 
 
 ###################################################
-### code chunk number 12: stream.Rnw:968-969
+### code chunk number 12: stream.Rnw:977-978
 ###################################################
 set.seed(1000) 
 
@@ -90,7 +90,7 @@ stream
 
 
 ###################################################
-### code chunk number 14: stream.Rnw:981-985 (eval = FALSE)
+### code chunk number 14: stream.Rnw:990-994 (eval = FALSE)
 ###################################################
 ## for(i in 1:4) {
 ##   plot(stream, 250, xlim = c(0, 1), ylim = c(0, 1))
@@ -134,7 +134,7 @@ arrows(.15,.15,.85,.85, col=rgb(.8,.8,.8,.6), lwd=10)
 
 
 ###################################################
-### code chunk number 19: stream.Rnw:1037-1040 (eval = FALSE)
+### code chunk number 19: stream.Rnw:1046-1049 (eval = FALSE)
 ###################################################
 ## reset_stream(stream)
 ## animate_data(stream, n = 10000, horizon = 100, 
@@ -142,7 +142,7 @@ arrows(.15,.15,.85,.85, col=rgb(.8,.8,.8,.6), lwd=10)
 
 
 ###################################################
-### code chunk number 20: stream.Rnw:1046-1049 (eval = FALSE)
+### code chunk number 20: stream.Rnw:1055-1058 (eval = FALSE)
 ###################################################
 ## library("animation")
 ## animation::ani.options(interval = .1)
@@ -150,130 +150,130 @@ arrows(.15,.15,.85,.85, col=rgb(.8,.8,.8,.6), lwd=10)
 
 
 ###################################################
-### code chunk number 21: stream.Rnw:1056-1058 (eval = FALSE)
+### code chunk number 21: stream.Rnw:1065-1067 (eval = FALSE)
 ###################################################
 ## saveHTML(ani.replay())
 ## saveGIF(ani.replay())
 
 
 ###################################################
-### code chunk number 22: stream.Rnw:1082-1084
+### code chunk number 22: stream.Rnw:1091-1092
 ###################################################
-library("stream") 
 set.seed(1000) 
 
 
 ###################################################
-### code chunk number 23: stream.Rnw:1086-1087
+### code chunk number 23: stream.Rnw:1094-1096
 ###################################################
+library("stream") 
 stream <- DSD_Gaussians(k = 3, d = 5) 
 
 
 ###################################################
-### code chunk number 24: stream.Rnw:1092-1093 (eval = FALSE)
+### code chunk number 24: stream.Rnw:1101-1102 (eval = FALSE)
 ###################################################
 ## write_stream(stream, "data.csv", n = 100, sep = ",") 
 
 
 ###################################################
-### code chunk number 25: stream.Rnw:1121-1125
+### code chunk number 25: stream.Rnw:1132-1136
 ###################################################
 file <- system.file("examples", "kddcup10000.data.gz", package = "stream")
 stream_file <- DSD_ReadCSV(gzfile(file),
-  take = c(1, 5, 6, 8:11, 13:20, 23:41), class = 42, k = 7)
+  take = c(1, 5, 6, 8:11, 13:20, 23:42), class = 42, k = 7)
 stream_file
 
 
 ###################################################
-### code chunk number 26: stream.Rnw:1137-1138
+### code chunk number 26: stream.Rnw:1148-1149
 ###################################################
 get_points(stream_file, n = 5)
 
 
 ###################################################
-### code chunk number 27: stream.Rnw:1145-1147
+### code chunk number 27: stream.Rnw:1156-1158
 ###################################################
 stream_scaled <- DSD_ScaleStream(stream_file, center = TRUE, scale = TRUE)
 get_points(stream_scaled, n = 5)
 
 
 ###################################################
-### code chunk number 28: stream.Rnw:1177-1179
+### code chunk number 28: stream.Rnw:1188-1190
 ###################################################
 library("stream") 
 set.seed(1000) 
 
 
 ###################################################
-### code chunk number 29: stream.Rnw:1181-1183
+### code chunk number 29: stream.Rnw:1192-1194
 ###################################################
 data("EuStockMarkets", package = "datasets")
 head(EuStockMarkets)
 
 
 ###################################################
-### code chunk number 30: stream.Rnw:1190-1192
+### code chunk number 30: stream.Rnw:1201-1203
 ###################################################
 replayer <- DSD_Memory(EuStockMarkets, k = NA) 
 replayer 
 
 
 ###################################################
-### code chunk number 31: stream.Rnw:1198-1200
+### code chunk number 31: stream.Rnw:1209-1211
 ###################################################
 get_points(replayer, n = 5)
 replayer
 
 
 ###################################################
-### code chunk number 32: stream.Rnw:1208-1209 (eval = FALSE)
+### code chunk number 32: stream.Rnw:1219-1220 (eval = FALSE)
 ###################################################
 ## get_points(replayer, n = 2000)
 
 
 ###################################################
-### code chunk number 33: stream.Rnw:1211-1213
+### code chunk number 33: stream.Rnw:1222-1224
 ###################################################
 err <- try(get_points(replayer, n = 2000))
 cat(err)
 
 
 ###################################################
-### code chunk number 34: stream.Rnw:1226-1228
+### code chunk number 34: stream.Rnw:1238-1240
 ###################################################
 reset_stream(replayer, pos = 100)
 replayer
 
 
 ###################################################
-### code chunk number 35: stream.Rnw:1527-1528
+### code chunk number 35: stream.Rnw:1542-1543
 ###################################################
 set.seed(1000) 
 
 
 ###################################################
-### code chunk number 36: stream.Rnw:1531-1533
+### code chunk number 36: stream.Rnw:1546-1548
 ###################################################
 library("stream") 
 stream <- DSD_Gaussians(k = 3, d = 2, noise = .05)
 
 
 ###################################################
-### code chunk number 37: stream.Rnw:1541-1543
+### code chunk number 37: stream.Rnw:1556-1558
 ###################################################
 dstream <- DSC_DStream(gridsize = .1, Cm = 1.2) 
 dstream
 
 
 ###################################################
-### code chunk number 38: stream.Rnw:1551-1553
+### code chunk number 38: stream.Rnw:1566-1568
 ###################################################
 update(dstream, stream, n = 500) 
 dstream
 
 
 ###################################################
-### code chunk number 39: stream.Rnw:1562-1563
+### code chunk number 39: stream.Rnw:1577-1578
 ###################################################
 head(get_centers(dstream))
 
@@ -291,34 +291,34 @@ plot(dstream, stream, grid = TRUE)
 
 
 ###################################################
-### code chunk number 42: stream.Rnw:1846-1850
+### code chunk number 42: stream.Rnw:1886-1890
 ###################################################
 library("stream") 
 stream <- DSD_Gaussians(k = 3, d = 2, noise = .05)
 dstream <- DSC_DStream(gridsize = .1) 
-update(dstream, stream, n = 500) 
+update(dstream, stream, n = 1000) 
 
 
 ###################################################
-### code chunk number 43: stream.Rnw:1858-1859
+### code chunk number 43: stream.Rnw:1898-1899
 ###################################################
 evaluate(dstream, stream, n = 100)
 
 
 ###################################################
-### code chunk number 44: stream.Rnw:1870-1871
+### code chunk number 44: stream.Rnw:1910-1911
 ###################################################
 evaluate(dstream, stream, measure = c("purity", "crand"), n = 500)
 
 
 ###################################################
-### code chunk number 45: stream.Rnw:1909-1910
+### code chunk number 45: stream.Rnw:1952-1953
 ###################################################
 set.seed(1000)
 
 
 ###################################################
-### code chunk number 46: stream.Rnw:1912-1917
+### code chunk number 46: stream.Rnw:1955-1960
 ###################################################
 stream <- DSD_Benchmark(1)
 dstream <- DSC_DStream(gridsize = .05, lambda = .01)
@@ -331,28 +331,34 @@ head(ev)
 ### code chunk number 47: evaluation
 ###################################################
 plot(ev[ , "points"], ev[ , "purity"], type = "l", 
-  ylim = c(0, 1), ylab = "Avg. Purity", xlab = "Points")
+  ylab = "Avg. Purity", xlab = "Points")
 
 
 ###################################################
-### code chunk number 48: stream.Rnw:1944-1948 (eval = FALSE)
+### code chunk number 48: stream.Rnw:1993-1994
 ###################################################
-## reset_stream(stream)
+set.seed(1000)
+
+
+###################################################
+### code chunk number 49: stream.Rnw:1997-2001 (eval = FALSE)
+###################################################
+## stream <- DSD_Benchmark(1)
 ## dstream <- DSC_DStream(gridsize = .05, lambda = .01)
-## r <- animate_cluster(dstream, stream, n = 5000, horizon = 100, 
-##   evaluationMeasure = "purity", xlim = c(0, 1), ylim = c(0, 1))
+## r <- animate_cluster(dstream, stream, horizon = 100, n = 5000, 
+##   measure = "purity", xlim = c(0, 1), ylim = c(0, 1))
 
 
 ###################################################
-### code chunk number 49: stream.Rnw:1978-1980
+### code chunk number 50: stream.Rnw:2031-2032
 ###################################################
-library("stream")
 set.seed(1000) 
 
 
 ###################################################
-### code chunk number 50: stream.Rnw:1983-1988
+### code chunk number 51: stream.Rnw:2035-2041
 ###################################################
+library("stream")
 stream <- DSD_Gaussians(k = 3, d = 2, noise = .05)
 dstream <- DSC_DStream(gridsize = .05, Cm = 1.5)
 
@@ -361,13 +367,13 @@ dstream
 
 
 ###################################################
-### code chunk number 51: recluster
+### code chunk number 52: recluster
 ###################################################
 plot(dstream, stream, type = "both")
 
 
 ###################################################
-### code chunk number 52: recluster2
+### code chunk number 53: recluster2
 ###################################################
 km <- DSC_Kmeans(k = 3, weighted = TRUE)
 recluster(km, dstream)
@@ -376,20 +382,20 @@ plot(km, stream, type = "both")
 
 
 ###################################################
-### code chunk number 53: stream.Rnw:2048-2049
+### code chunk number 54: stream.Rnw:2102-2103
 ###################################################
 evaluate(km, stream, measure = c("purity", "crand", "SSQ"), n = 1000)
 
 
 ###################################################
-### code chunk number 54: stream.Rnw:2054-2056
+### code chunk number 55: stream.Rnw:2108-2110
 ###################################################
 evaluate(km, stream, c(measure = "purity", "crand", "SSQ"), n = 1000, 
   assign = "macro")
 
 
 ###################################################
-### code chunk number 55: stream.Rnw:2078-2081
+### code chunk number 56: stream.Rnw:2133-2136
 ###################################################
 points <- get_points(stream, n = 100)
 assignment <- get_assignment(dstream, points, type = "macro")
@@ -397,7 +403,7 @@ assignment
 
 
 ###################################################
-### code chunk number 56: silhouette
+### code chunk number 57: silhouette
 ###################################################
 assignment[is.na(assignment)] <- 0L
 library("cluster")
@@ -405,27 +411,7 @@ plot(silhouette(assignment, dist = dist(points)))
 
 
 ###################################################
-### code chunk number 57: stream.Rnw:2174-2189 (eval = FALSE)
-###################################################
-## DSD_UniformNoise <- function(d = 2, range = NULL) {
-##   if(is.null(range)) range <- matrix(c(0, 1), ncol = 2, nrow = d, 
-##     byrow = TRUE)
-##   structure(list(description = "Uniform Noise Data Stream", d = d, 
-##     k = NA_integer_, range = range),
-##         class = c("DSD_UniformNoise", "DSD_R", "DSD"))
-##   }
-##   
-## get_points.DSD_UniformNoise <- function(x, n = 1, 
-##   assignment = FALSE, ...) {
-##     data <- as.data.frame(t(replicate(n, 
-##       runif(x$d, min = x$range[ , 1], max = x$range[ , 2]))))
-##     if(assignment) attr(data, "assignment") <- rep(NA_integer_, n)
-##     data
-## }
-
-
-###################################################
-### code chunk number 58: stream.Rnw:2282-2283
+### code chunk number 58: stream.Rnw:2337-2338
 ###################################################
 set.seed(1000) 
 
@@ -440,7 +426,7 @@ plot(stream)
 
 
 ###################################################
-### code chunk number 60: stream.Rnw:2308-2316
+### code chunk number 60: stream.Rnw:2364-2372
 ###################################################
 algorithms <- list(
   'Sample' = DSC_TwoStage(micro = DSC_Sample(k = 100), 
@@ -453,7 +439,7 @@ algorithms <- list(
 
 
 ###################################################
-### code chunk number 61: stream.Rnw:2326-2330
+### code chunk number 61: stream.Rnw:2382-2386
 ###################################################
 for(a in algorithms) {
   reset_stream(stream) 
@@ -462,7 +448,7 @@ for(a in algorithms) {
 
 
 ###################################################
-### code chunk number 62: stream.Rnw:2335-2336
+### code chunk number 62: stream.Rnw:2391-2392
 ###################################################
 sapply(algorithms, nclusters, type = "micro")
 
@@ -474,7 +460,7 @@ op <- par(no.readonly = TRUE)
 layout(mat = matrix(1:length(algorithms), ncol = 2))
 for(a in algorithms) {
   reset_stream(stream) 
-  plot(a, stream, main = a$description, type = "micro")
+  plot(a, stream, main = description(a), type = "micro")
 }
 par(op)
 
@@ -486,14 +472,14 @@ op <- par(no.readonly = TRUE)
 layout(mat = matrix(1:length(algorithms), ncol = 2))
 for(a in algorithms) {
   reset_stream(stream) 
-  plot(a, stream, main = a$description, 
+  plot(a, stream, main = description(a), 
     assignment = TRUE, weight = FALSE, type = "micro")
 }
 par(op)
 
 
 ###################################################
-### code chunk number 65: stream.Rnw:2414-2421
+### code chunk number 65: stream.Rnw:2470-2477
 ###################################################
 sapply(algorithms, FUN=function(a) {
   reset_stream(stream, pos = 1001) 
@@ -511,13 +497,13 @@ op <- par(no.readonly = TRUE)
 layout(mat=matrix(1:length(algorithms), ncol = 2))
 for(a in algorithms) {
   reset_stream(stream) 
-  plot(a, stream, main = a$description, type = "both")
+  plot(a, stream, main = description(a), type = "both")
 }
 par(op)
 
 
 ###################################################
-### code chunk number 67: stream.Rnw:2463-2469
+### code chunk number 67: stream.Rnw:2521-2527
 ###################################################
 sapply(algorithms, FUN = function(a) {
   reset_stream(stream, pos = 1001) 
@@ -528,75 +514,79 @@ sapply(algorithms, FUN = function(a) {
 
 
 ###################################################
-### code chunk number 68: stream.Rnw:2489-2490
+### code chunk number 68: stream.Rnw:2548-2549
 ###################################################
 set.seed(0)
 
 
 ###################################################
-### code chunk number 69: stream.Rnw:2493-2494
+### code chunk number 69: stream.Rnw:2552-2553
 ###################################################
 stream <- DSD_Memory(DSD_Benchmark(1), n = 5000)
 
 
 ###################################################
-### code chunk number 70: stream.Rnw:2504-2512
+### code chunk number 70: stream.Rnw:2563-2571
 ###################################################
 algorithms <- list(
   'Sample' = DSC_TwoStage(micro = DSC_Sample(k = 100, biased = TRUE), 
     macro = DSC_Kmeans(k = 2)), 
   'Window' = DSC_TwoStage(micro = DSC_Window(horizon = 100, lambda = .01), 
     macro = DSC_Kmeans(k = 2)), 
-  'D-Stream' = DSC_DStream(gridsize = .05, lambda = .01),
-  'DBSTREAM' = DSC_DBSTREAM(r = .02, lambda = .01)
+  'D-Stream' = DSC_DStream(gridsize = .1, lambda = .01),
+  'DBSTREAM' = DSC_DBSTREAM(r = .05, lambda = .01)
 )
 
 
 ###################################################
-### code chunk number 71: stream.Rnw:2520-2526
+### code chunk number 71: stream.Rnw:2580-2585
 ###################################################
 evaluation <- lapply(algorithms, FUN = function(a) {
   reset_stream(stream) 
-  evaluate_cluster(a, stream, 
-    type = "macro", assign = "micro", measure = "crand", 
-    n = 5000, horizon = 250)
+  evaluate_cluster(a, stream, horizon = 100, n = 5000, measure = "crand",
+    type = "macro", assign = "micro")
 })
 
 
 ###################################################
-### code chunk number 72: dynamic
+### code chunk number 72: stream.Rnw:2601-2604
 ###################################################
 Position <- evaluation[[1]][ , "points"]
 cRand <- sapply(evaluation, FUN = function(x) x[ , "cRand"])
 head(cRand)
+
+
+###################################################
+### code chunk number 73: dynamic
+###################################################
 matplot(Position, cRand, type = "l", lwd = 2)
 legend("bottomleft", legend = names(evaluation), 
   col = 1:6, lty = 1:6, bty = "n", lwd = 2)
 
 
 ###################################################
-### code chunk number 73: dynamic_box
+### code chunk number 74: dynamic_box
 ###################################################
-boxplot(cRand, las = 2)
+boxplot(cRand, las = 2, cex.axis = .8)
 
 
 ###################################################
-### code chunk number 74: stream.Rnw:2596-2604 (eval = FALSE)
+### code chunk number 75: stream.Rnw:2662-2670 (eval = FALSE)
 ###################################################
 ## library("stream")
 ## con <- gzcon(
 ##   url(paste("http://archive.ics.uci.edu/ml/machine-learning-databases/",
 ##     "kddcup99-mld/kddcup.data.gz", sep="")))
 ## 
-## stream <- DSD_ReadCSV(con, take=c(1, 5, 6, 8:11, 13:20, 23:41), 
+## stream <- DSD_ReadCSV(con, take=c(1, 5, 6, 8:11, 13:20, 23:42), 
 ##     class=42, k=7)
 ## stream2 <- DSD_ScaleStream(stream, n=1000)
 
 
 ###################################################
-### code chunk number 75: stream.Rnw:2610-2612 (eval = FALSE)
+### code chunk number 76: stream.Rnw:2676-2678 (eval = FALSE)
 ###################################################
-## dstream <- DSC_DStream(gridsize = .5, gaptime = 10000L, lambda=.01)
-## update(dstream, stream2, n=4000000, verbose=TRUE)
+## dstream <- DSC_DStream(gridsize = .5, gaptime = 10000L, lambda = .01)
+## update(dstream, stream2, n = 4000000, verbose = TRUE)
 
 
